from __future__ import annotations

from chalk.integrations.catalogs.base_catalog import BaseCatalog


class GlueCatalog(BaseCatalog):
    """
    A class to represent an AWS Glue Catalog.

    Attributes:
        name (str): The name of the Glue Catalog.
        skip_default_database (bool): Whether to skip the default database. Defaults to True.
        aws_role_arn (str | None): The AWS role ARN to assume for accessing the Glue Catalog.
        aws_region (str | None): The AWS region where the Glue Catalog is located.
        aws_profile (str | None): The AWS profile to use for accessing the Glue Catalog.
        aws_secret_key_id (str | None): The AWS secret key ID for accessing the Glue Catalog.
        aws_secret_access_key (str | None): The AWS secret access key for accessing the Glue Catalog.
        aws_session_token (str | None): The AWS session token for accessing the Glue Catalog.
        endpoint_url (str | None): The endpoint URL for the Glue Catalog.
        catalog_id (str | None): The catalog ID for the Glue Catalog.
        cache_ttl (int): The cache time-to-live in seconds. Defaults to 600.

    Methods:
        __init__: Initializes the GlueCatalog with the provided parameters.
    """

    def __init__(
        self,
        name: str,
        skip_default_database: bool = True,
        aws_role_arn: str | None = None,
        aws_region: str | None = None,
        aws_profile: str | None = None,
        aws_secret_key_id: str | None = None,
        aws_secret_access_key: str | None = None,
        aws_session_token: str | None = None,
        endpoint_url: str | None = None,
        catalog_id: str | None = None,
        cache_ttl: int = 600,
    ) -> None:
        super().__init__()
        self.name = name
        self.cache_ttl = cache_ttl
        self.skip_default_database = skip_default_database
        self.aws_role_arn = aws_role_arn
        self.aws_region = aws_region
        self.aws_profile = aws_profile
        self.aws_secret_key_id = aws_secret_key_id
        self.aws_secret_access_key = aws_secret_access_key
        self.aws_session_token = aws_session_token
        self.endpoint_url = endpoint_url
        self.catalog_id = catalog_id
